pub trait ItemToKey<Key: ?Sized>: for<'lend> LendItem<'lend> {
// Required method
fn item_to_key(item: LentItem<'_, Self>) -> &Key;
}Expand description
Convert one of the items of an iterator into a Key reference, intended for use with a
SeekableLendingIterator.
This conversion is expected to be cheap.
Required Methods
Sourcefn item_to_key(item: LentItem<'_, Self>) -> &Key
fn item_to_key(item: LentItem<'_, Self>) -> &Key
Convert one of the items of an iterator into a Key reference, intended for use with
a SeekableLendingIterator.
This conversion is expected to be cheap.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".